#Vignettes that depend on internet access have been precompiled:

library(knitr)
knit("vignettes/intro.Rmdin", "vignettes/intro.Rmd")
